@@ -70,13 +70,13 @@ DBIx::Custom::SQLite - DBIx::Custom SQLite implementation
     
     # New
     my $dbi = DBIx::Custom::SQLite->new(user => 'taro', $password => 'kliej&@K',
-                                       database => 'sample.db');
+                                        database => 'sample');
     
     # Insert 
     $dbi->insert('books', {title => 'perl', author => 'taro'});
     
     # Update 
-    # same as 'update books set (title = 'aaa', author = 'ken') where id = 5;
+    # same as 'update books set title = 'aaa', author = 'ken' where id = 5;
     $dbi->update('books', {title => 'aaa', author => 'ken'}, {id => 5});
     
     # Delete
@@ -95,7 +95,7 @@ DBIx::Custom::SQLite - DBIx::Custom SQLite implementation
     $dbi->select('books', [qw/author title/], {author => 'taro'},
                  'order by id limit 1');
 
-=head1 See DBIx::Custom and DBI::Custom::Basic documentation
+=head1 See DBIx::Custom and DBI::Custom::Basic documentation at first
 
 This class is L<DBIx::Custom::Basic> subclass.
 and L<DBIx::Custom::Basic> is L<DBIx::Custom> subclass
@@ -103,31 +103,48 @@ and L<DBIx::Custom::Basic> is L<DBIx::Custom> subclass
 You can use all methods of L<DBIx::Custom::Basic> and <DBIx::Custom>
 Please see L<DBIx::Custom::Basic> and <DBIx::Custom> documentation
 
-=head1 Object methods
+=head1 methods
 
 =head2 connect
 
-This override L<DBIx::Custom> connect.
+Connect to database
 
-    # Connect to database
+    $self = $self->connect;
+    
+    # Sample
     $dbi->connect;
 
-If database attribute is set, automatically data source is created and connect
+This override L<DBIx::Custom> connect.
+
+If you set database, data source is automatically created and connect
 
 =head2 connect_memory
 
-    # Connect memory database
-    $self = $dbi->connect_memory;
+Connect memory database
+
+    $self = $self->connect_memory;
+    
+    # Sample
+    $dbi->connect_memory;
 
 =head2 reconnect_memory
 
-    # Reconnect memory database
+Reconnect to memory databsse
+
+    $self = $self->reconnect_memory;
+    
+    # Sample
     $self = $dbi->reconnect_memory;
 
 =head2 last_insert_id
 
-    # Get last insert id
+Get last insert id
+
     $last_insert_id = $self->last_insert_id;
+    
+    # Sample
+    $dbi->insert('books', {title => 'Perl', author => 'taro'});
+    $last_insert_id = $dbi->last_insert_id;
 
 This is equal to SQLite function
 
